package com.mysql.jdbc.jdbc2.optional;

import com.mysql.jdbc.Connection;
import com.mysql.jdbc.SQLError;
import java.sql.SQLException;
import java.util.Enumeration;
import java.util.Hashtable;
import javax.sql.ConnectionEvent;
import javax.sql.ConnectionEventListener;
import javax.sql.PooledConnection;

/* loaded from: com_mysql_jdbc_jdbc2_optional.jar:com/mysql/jdbc/jdbc2/optional/MysqlPooledConnection.class */
public class MysqlPooledConnection implements PooledConnection {
    public static final int CONNECTION_ERROR_EVENT = 1;
    public static final int CONNECTION_CLOSED_EVENT = 2;
    private Connection physicalConn;
    private java.sql.Connection logicalHandle = null;
    private Hashtable eventListeners = new Hashtable(10);

    public MysqlPooledConnection(Connection connection) {
        this.physicalConn = connection;
    }

    @Override // javax.sql.PooledConnection
    public synchronized void addConnectionEventListener(ConnectionEventListener connectioneventlistener) {
        if (this.eventListeners != null) {
            this.eventListeners.put(connectioneventlistener, connectioneventlistener);
        }
    }

    @Override // javax.sql.PooledConnection
    public synchronized void removeConnectionEventListener(ConnectionEventListener connectioneventlistener) {
        if (this.eventListeners != null) {
            this.eventListeners.remove(connectioneventlistener);
        }
    }

    @Override // javax.sql.PooledConnection
    public synchronized java.sql.Connection getConnection() throws SQLException {
        return getConnection(true, false);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public synchronized java.sql.Connection getConnection(boolean resetServerState, boolean forXa) throws SQLException {
        if (this.physicalConn == null) {
            SQLException sqlException = SQLError.createSQLException("Physical Connection doesn't exist");
            callListener(1, sqlException);
            throw sqlException;
        }
        try {
            if (this.logicalHandle != null) {
                ((ConnectionWrapper) this.logicalHandle).close(false);
            }
            if (resetServerState) {
                this.physicalConn.resetServerState();
            }
            this.logicalHandle = ConnectionWrapper.getInstance(this, this.physicalConn, forXa);
            return this.logicalHandle;
        } catch (SQLException sqlException2) {
            callListener(1, sqlException2);
            throw sqlException2;
        }
    }

    @Override // javax.sql.PooledConnection
    public synchronized void close() throws SQLException {
        if (this.physicalConn != null) {
            this.physicalConn.close();
        }
        this.physicalConn = null;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public synchronized void callListener(int eventType, SQLException sqlException) {
        if (this.eventListeners == null) {
            return;
        }
        Enumeration enumeration = this.eventListeners.keys();
        ConnectionEvent connectionevent = new ConnectionEvent(this, sqlException);
        while (enumeration.hasMoreElements()) {
            ConnectionEventListener connectioneventlistener = (ConnectionEventListener) enumeration.nextElement();
            ConnectionEventListener connectioneventlistener1 = (ConnectionEventListener) this.eventListeners.get(connectioneventlistener);
            if (eventType == 2) {
                connectioneventlistener1.connectionClosed(connectionevent);
            } else if (eventType == 1) {
                connectioneventlistener1.connectionErrorOccurred(connectionevent);
            }
        }
    }
}
